@@ -11,11 +11,11 @@ Game::Planeshift::Info - A module to retrieve players' data on the main Planeshi
 
 =head1 VERSION
 
-Version 0.3
+Version 0.4
 
 =cut
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ the default web page used to retrieve informations is on the Laanx server : http
 
     my $ps = Game::Planeshift::Info->new(
     	encoding => 'utf-8',
-    	players => ['Baston', 'Ehasara', 'Narita', 'Setill', 'Soshise', 'Mardun', 'Caules', 'Javeroal']
+    	players => ['Anfa','Baston', 'Caules', 'Ehasara', 'Javeroal', 'Mardun', 'Narita', 'Setill', 'Soshise']
     );
     my $data = $ps->retrieve_info ;
 
@@ -68,13 +68,14 @@ Here is an example :
 	use Data::Dumper
 	use Game::Planeshift::Info ;
 	
-	my my $ps = Game::Planeshift::Info->new(players => ['Baston', 'Ehasara', 'Narita', 'Setill', 'Soshise', 'Mardun', 'Caules', 'Javeroal']) ;
+	my my $ps = Game::Planeshift::Info->new(players => ['Anfa','Baston', 'Caules', 'Ehasara', 'Javeroal', 'Mardun', 'Narita', 'Setill', 'Soshise']) ;
 	print Dumper( $ps->retrieve_info );
 
 On screen you will have :
 
 	$VAR1 = {
 		'online_players' => {
+					'Anfa' => 1,
 					'Caules' => 0,
 					'Narita' => 0,
 					'Javeroal' => 1,
@@ -231,6 +232,11 @@ sub _parse_content
 					if(defined($key))
 					{
 						$key=~ s/\s+/_/g;
+						if($key eq 'Total_Online')
+						{
+							$value=~ s/\s+//g;
+							$value = 0 unless($value) ;
+						}
 						$data->{server_status}->{$key} = $value;
 					}
 				}
@@ -570,6 +576,7 @@ The XML generated by this method on the data previously retrieve is :
 		</server-status>
 		<online-players>
 			<player name="Javeroal" />
+			<player name="Anfa" />
 		</online-players>
 		<most-active-players>
 			<player name="Javeroal" hours="1963.53"/>
